#!/bin/bash

function check_ports {
    echo "checking ports"

    ## FireHol
    if (test -f /var/lock/firehol);
    then fh_running=1 && echo "FireHol is running";
    else fh_running=0 && echo "FireHol is stopped";
    fi

    ## TinyProxy
    pid_tp="`pidof tinyproxy | tr -d [:space:]`"
    if (test -z $pid_tp);
    then tp_running=0 && echo "TinyProxy is stopped"; 
    else tp_running=1 && echo "TinyProxy is running";
    fi

    ## DansGuardian
    pid_dg="`pidof dansguardian | tr -d [:space:]`"
    if (test -z $pid_dg);
    then dg_running=0 && echo "DansGuardian is stopped";
    else dg_running=1 && echo "DansGuardian is running";
    fi

    if (test $fh_running -eq 1) && (test $tp_running -eq 1) && (test $dg_running -eq 1);
    then
	echo "All OK! Everything is running"
	return 0
    else
	echo "There was an error"
	return 1
    fi
}

function start {
    echo "starting all"
    gksudo /etc/init.d/firehol start;
    gksudo /etc/init.d/tinyproxy start;
    gksudo /etc/init.d/dansguardian start;
}

function stop {
    echo "stopping all"
    gksudo /etc/init.d/firehol stop;
    gksudo /etc/init.d/tinyproxy stop;
    gksudo /etc/init.d/dansguardian stop;
}

set_ports()
{
    echo "setting ports"
    yourpath/set_ports.sh $1 $2
}

proxyport_start_index=3128
proxyport_end_index=3129
filterport_start_index=8080
filterport_end_index=8081

for (( proxyport = $proxyport_start_index ; proxyport <= $proxyport_end_index ; proxyport++ ))
do
    for (( filterport = $filterport_start_index ; filterport <= $filterport_end_index ; filterport++ ))
    do
	echo proxyport=$proxyport filterport=$filterport
	echo "==========================================="
	set_ports $proxyport $filterport
	echo "==========================================="
	stop
	echo "==========================================="
	start
	echo "==========================================="
	if check_ports
	then
	    exit 0
	fi
	echo "==========================================="
    done;
done;
